import { Component, h, Host, State, Event } from '@stencil/core';
import { SmileyState } from '../../types/smiley';
import { SmileyAsset } from '../asset/smiley.asset';
import { translate } from '../../utils/translations.utils';
import { debounce } from '../../utils/debounce.utils';
/**
 * @slot question - An optional slot to display your personal question
 */
export class Smiley {
  constructor() {
    this.stateLabel = 'hidden';
    this.debounceState = debounce(() => this.state.emit(this.smiley));
  }
  next() {
    if (!this.smiley) {
      this.initState();
      return;
    }
    switch (this.smiley) {
      case SmileyState.BAD:
        this.smiley = SmileyState.SUPER;
        break;
      case SmileyState.NOT_WELL:
        this.smiley = SmileyState.BAD;
        break;
      case SmileyState.OKAY:
        this.smiley = SmileyState.NOT_WELL;
        break;
      case SmileyState.SUPER:
        this.smiley = SmileyState.WELL;
        break;
      default:
        this.smiley = SmileyState.OKAY;
    }
    this.debounceState();
  }
  initState() {
    this.smiley = SmileyState.SUPER;
    this.debounceState();
    setTimeout(() => (this.stateLabel = 'visible'), 50);
  }
  render() {
    return (h(Host, null,
      this.renderText(),
      h("button", { onClick: () => this.next(), name: "smiley" },
        h(SmileyAsset, { smiley: this.smiley }))));
  }
  renderText() {
    if (!this.smiley) {
      return (h("label", { key: "question", htmlFor: "smiley", class: "question" },
        h("slot", { name: "question" }, translate('question'))));
    }
    return (h("label", { key: "state", htmlFor: "smiley", class: `state ${this.stateLabel}` }, translate(this.smiley)));
  }
  static get is() { return "bonjour-smiley"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["smiley.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["smiley.css"]
  }; }
  static get states() { return {
    "smiley": {},
    "stateLabel": {}
  }; }
  static get events() { return [{
      "method": "state",
      "name": "state",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits the state (super, well, okay, not_well or bad) that has been selected."
      },
      "complexType": {
        "original": "SmileyState",
        "resolved": "SmileyState.BAD | SmileyState.NOT_WELL | SmileyState.OKAY | SmileyState.SUPER | SmileyState.WELL",
        "references": {
          "SmileyState": {
            "location": "import",
            "path": "../../types/smiley"
          }
        }
      }
    }]; }
}
